discoveryError property
If set, the discovery stream emits this error (after any discoveryResults) so tests can exercise error-surfacing paths.
Implementation
Object? discoveryError;
If set, the discovery stream emits this error (after any discoveryResults) so tests can exercise error-surfacing paths.
Object? discoveryError;